==> dasu_4.11.jar: edu/northwestern/dasu/sandbox/applet/RemoteAMCPolicy.java <==
/**
 * Dasu Project
 *
 * File:         TestPolicy.java
 * RCS:          $Id: TestPolicy.java,v 1.0 Jul 15, 2012 10:05:07 AM mas939 Exp $
 * Description:  TestPolicy class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 15, 2012 at 10:05:07 AM
 * Language:     Java
 * Package:      edu.northwestern.zookeeper
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.sandbox.applet;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RemoteAMCPolicy class ...
 */

import java.lang.management.ManagementPermission;
import java.net.MalformedURLException;
import java.net.SocketPermission;
import java.net.URL;
import java.security.*;
import java.util.*;

public class RemoteAMCPolicy extends Policy {
	
    private static CodeSource appCodeSource;
    private static PermissionCollection permissions;
    private static Permissions allPermissions;
    private static boolean allowAll = false;

    // assume that RemoteAMCPolicy and the application are from the same code source 
    static {
        appCodeSource = RemoteAMCPolicy.class.getProtectionDomain().getCodeSource();
        permissions = new MyPermissionCollection();
        allPermissions = new Permissions();
        allPermissions.add(new AllPermission());
        
    }

    static class MyPermissionCollection extends PermissionCollection {
        
    	public void add(Permission permission) {
        }

        public boolean implies(Permission permission) {
        	
            if (permission instanceof PropertyPermission) {
                return getAllowedPropertyPermissions().implies(permission);
            }
            
            if (permission instanceof SocketPermission) {
            	return getAllowedSocketPermissions().implies(permission);
            }
            
            if (permission instanceof RuntimePermission) {
            	return getAllowedRuntimePermissions().implies(permission);
            }
            
           // if (permission instanceof FilePermission) {
           // 	return getAllowedFilePermissions().implies(permission);
           //}
            //
            //if (permission instanceof ManagementPermission) {
            //	return getAllowedManagementPermissions().implies(permission);
            //}

            // we disallow all other permissions
            return false;
        }
        
        public Enumeration<Permission> elements() {
            
        	return new Enumeration<Permission>() {
                public boolean hasMoreElements() {
                	System.out.println("permissoin");
                    return false;
                }

                public Permission nextElement() {
                	System.out.println("permissoin");
                    return null;
                }
            };
        }

        private Permissions getAllowedPropertyPermissions() {
            Permissions perms = new Permissions();
            perms.add(new PropertyPermission("user.dir", "read"));
            perms.add(new PropertyPermission("user.home", "read"));
            
            //too dangerous
            //perms.add(new PropertyPermission("*", "read,write")); 
            return perms;
        }
        
        private Permissions getAllowedSocketPermissions() {
            Permissions perms = new Permissions();
            perms.add(new SocketPermission("127.0.0.1:*", "connect,accept,resolve,listen"));
            return perms;
        }
        
        private Permissions getAllowedRuntimePermissions() {
        	Permissions perms = new Permissions();
        	perms.add(new RuntimePermission("getClassLoader"));
        	perms.add(new RuntimePermission("modifyThread"));
        	 
        	//too dangerous
        	//perms.add(new RuntimePermission("createClassLoader")); 
        	//perms.add(new RuntimePermission("accessClassInPackage.sun.misc")); 
        	//perms.add(new RuntimePermission("accessDeclaredMembers")); 
        	//perms.add(new RuntimePermission("suppressAccessChecks"));
        	//perms.add(new RuntimePermission("modifyThreadGroup")); 
        	
        	return perms;
        }

        //too dangerous?
        //private Permissions getAllowedFilePermissions() {
        //	Permissions perms = new Permissions();
        //	perms.add(new FilePermission("<<ALL FILES>>", "read"));
        //	return perms;
        //}
        //
        //
        //private Permissions getAllowedManagementPermissions() {
        //	Permissions perms = new Permissions();
        //	perms.add(new ManagementPermission("monitor"));
        //	return perms;
        //}

    };
    
    public PermissionCollection getPermissions(CodeSource codesource) {
    	
    	//System.out.println(codesource.getLocation());
        if (!appCodeSource.equals(codesource) && !allowAll)
    		return permissions;
    	return allPermissions;
    	
    	//System.out.println(codesource.getLocation());
    	//if (codesource.toString().contains("sandbox")) {
        //   return allPermissions;
        //}         
        //return allPermissions; //return allPermissions;
    }

    public boolean implies(ProtectionDomain domain, Permission permission) {    	
    	return getPermissions(domain.getCodeSource()).implies(permission);
    }

    public PermissionCollection getPermissions(ProtectionDomain domain) {
        return getPermissions(domain.getCodeSource());
    }

    public void refresh() {

    	if ( allowAll )
    		allowAll = false;
    	else
    		allowAll = true;
    	
//    	if ( appCodeSource.equals(RemoteAMCPolicy.class.getProtectionDomain().getCodeSource()) ) {
//    	
//	    	try {
//				appCodeSource = new CodeSource(new URL("file:edu.northwestern.dasu"), new java.security.cert.Certificate[]{});
//			} catch (MalformedURLException e) {
//				e.printStackTrace();
//			}
//    	}
//    	else {
//        	appCodeSource = RemoteAMCPolicy.class.getProtectionDomain().getCodeSource();
//    	}


    }
    
}

==> dasu_5.31.jar: edu/northwestern/dasu/sandbox/applet/RemoteAMCPolicy.java <==
/**
 * Dasu Project
 *
 * File:         TestPolicy.java
 * RCS:          $Id: TestPolicy.java,v 1.0 Jul 15, 2012 10:05:07 AM mas939 Exp $
 * Description:  TestPolicy class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 15, 2012 at 10:05:07 AM
 * Language:     Java
 * Package:      edu.northwestern.zookeeper
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2012, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.sandbox.applet;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RemoteAMCPolicy class ...
 */

import java.net.SocketPermission;
import java.security.*;
import java.util.*;

public class RemoteAMCPolicy extends Policy {
	
    private static CodeSource appCodeSource;
    private static PermissionCollection permissions;
    private static Permissions allPermissions;
    private static boolean allowAll = false;

    // assume that RemoteAMCPolicy and the application are from the same code source 
    static {
        appCodeSource = RemoteAMCPolicy.class.getProtectionDomain().getCodeSource();
        permissions = new MyPermissionCollection();
        allPermissions = new Permissions();
        allPermissions.add(new AllPermission());
        
    }

    static class MyPermissionCollection extends PermissionCollection {
        
    	public void add(Permission permission) {
        }

        public boolean implies(Permission permission) {
        	
            if (permission instanceof PropertyPermission) {
                return getAllowedPropertyPermissions().implies(permission);
            }
            
            if (permission instanceof SocketPermission) {
            	return getAllowedSocketPermissions().implies(permission);
            }
            
            if (permission instanceof RuntimePermission) {
            	return getAllowedRuntimePermissions().implies(permission);
            }
            
           // if (permission instanceof FilePermission) {
           // 	return getAllowedFilePermissions().implies(permission);
           //}
            //
            //if (permission instanceof ManagementPermission) {
            //	return getAllowedManagementPermissions().implies(permission);
            //}

            // disallow all other permissions
            return false;
        }
        
        public Enumeration<Permission> elements() {
            
        	return new Enumeration<Permission>() {
                public boolean hasMoreElements() {
                	System.out.println("permission");
                    return false;
                }

                public Permission nextElement() {
                	System.out.println("permission");
                    return null;
                }
            };
        }

        private Permissions getAllowedPropertyPermissions() {
            Permissions perms = new Permissions();
            perms.add(new PropertyPermission("user.dir", "read"));
            perms.add(new PropertyPermission("user.home", "read"));
            
            //too dangerous
            //perms.add(new PropertyPermission("*", "read,write")); 
            return perms;
        }
        
        private Permissions getAllowedSocketPermissions() {
            Permissions perms = new Permissions();
            perms.add(new SocketPermission("127.0.0.1:*", "connect,accept,resolve,listen"));
            perms.add(new SocketPermission("localhost:*", "connect,accept,resolve,listen"));
            return perms;
        }
        
        private Permissions getAllowedRuntimePermissions() {
        	Permissions perms = new Permissions();
        	perms.add(new RuntimePermission("getClassLoader"));
        	perms.add(new RuntimePermission("modifyThread"));
        	 
        	//too dangerous
        	//perms.add(new RuntimePermission("createClassLoader")); 
        	//perms.add(new RuntimePermission("accessClassInPackage.sun.misc")); 
        	//perms.add(new RuntimePermission("accessDeclaredMembers")); 
        	//perms.add(new RuntimePermission("suppressAccessChecks"));
        	//perms.add(new RuntimePermission("modifyThreadGroup")); 
        	
        	return perms;
        }

        //too dangerous?
        //private Permissions getAllowedFilePermissions() {
        //	Permissions perms = new Permissions();
        //	perms.add(new FilePermission("<<ALL FILES>>", "read"));
        //	return perms;
        //}
        //
        //
        //private Permissions getAllowedManagementPermissions() {
        //	Permissions perms = new Permissions();
        //	perms.add(new ManagementPermission("monitor"));
        //	return perms;
        //}

    };
    
    public PermissionCollection getPermissions(CodeSource codesource) {
    	
    	//System.out.println(codesource.getLocation());
        if (!appCodeSource.equals(codesource) && !allowAll)
    		return permissions;
    	return allPermissions;
    	
    }

    public boolean implies(ProtectionDomain domain, Permission permission) {    	
    	return getPermissions(domain.getCodeSource()).implies(permission);
    }

    public PermissionCollection getPermissions(ProtectionDomain domain) {
        return getPermissions(domain.getCodeSource());
    }

    public void refresh() {

    	if ( allowAll )
    		allowAll = false;
    	else
    		allowAll = true;
    	
    	System.out.println("RemoteAMCPolicy: allowAll: " + allowAll);
//    	if ( appCodeSource.equals(RemoteAMCPolicy.class.getProtectionDomain().getCodeSource()) ) {
//    	
//	    	try {
//				appCodeSource = new CodeSource(new URL("file:edu.northwestern.dasu"), new java.security.cert.Certificate[]{});
//			} catch (MalformedURLException e) {
//				e.printStackTrace();
//			}
//    	}
//    	else {
//        	appCodeSource = RemoteAMCPolicy.class.getProtectionDomain().getCodeSource();
//    	}


    }
    
}
